' . lang("Created by") . ': '
. ''
@@ -1688,137 +1558,137 @@
$create .= '';
}
- $GLOBALS['phpgw']->template->set_var('lang_home',lang('Home'));
- $GLOBALS['phpgw']->template->set_var('lang_business',lang('Business'));
- $GLOBALS['phpgw']->template->set_var('lang_personal',lang('Personal'));
+ $this->template->set_var('lang_home',lang('Home'));
+ $this->template->set_var('lang_business',lang('Business'));
+ $this->template->set_var('lang_personal',lang('Personal'));
- $GLOBALS['phpgw']->template->set_var('lang_lastname',lang('Last Name'));
- $GLOBALS['phpgw']->template->set_var('lastname',$lastname);
- $GLOBALS['phpgw']->template->set_var('lang_firstname',lang('First Name'));
- $GLOBALS['phpgw']->template->set_var('firstname',$firstname);
- $GLOBALS['phpgw']->template->set_var('lang_middle',lang('Middle Name'));
- $GLOBALS['phpgw']->template->set_var('middle',$middle);
- $GLOBALS['phpgw']->template->set_var('lang_prefix',lang('Prefix'));
- $GLOBALS['phpgw']->template->set_var('prefix',$prefix);
- $GLOBALS['phpgw']->template->set_var('lang_suffix',lang('Suffix'));
- $GLOBALS['phpgw']->template->set_var('suffix',$suffix);
- $GLOBALS['phpgw']->template->set_var('lang_birthday',lang('Birthday'));
- $GLOBALS['phpgw']->template->set_var('birthday',$birthday);
+ $this->template->set_var('lang_lastname',lang('Last Name'));
+ $this->template->set_var('lastname',$lastname);
+ $this->template->set_var('lang_firstname',lang('First Name'));
+ $this->template->set_var('firstname',$firstname);
+ $this->template->set_var('lang_middle',lang('Middle Name'));
+ $this->template->set_var('middle',$middle);
+ $this->template->set_var('lang_prefix',lang('Prefix'));
+ $this->template->set_var('prefix',$prefix);
+ $this->template->set_var('lang_suffix',lang('Suffix'));
+ $this->template->set_var('suffix',$suffix);
+ $this->template->set_var('lang_birthday',lang('Birthday'));
+ $this->template->set_var('birthday',$birthday);
- $GLOBALS['phpgw']->template->set_var('lang_company',lang('Company Name'));
- $GLOBALS['phpgw']->template->set_var('company',$company);
- $GLOBALS['phpgw']->template->set_var('lang_department',lang('Department'));
- $GLOBALS['phpgw']->template->set_var('department',$department);
- $GLOBALS['phpgw']->template->set_var('lang_title',lang('Title'));
- $GLOBALS['phpgw']->template->set_var('title',$title);
- $GLOBALS['phpgw']->template->set_var('lang_email',lang('Business Email'));
- $GLOBALS['phpgw']->template->set_var('email',$email);
- $GLOBALS['phpgw']->template->set_var('lang_email_type',lang('Business EMail Type'));
- $GLOBALS['phpgw']->template->set_var('email_type',$email_type);
- $GLOBALS['phpgw']->template->set_var('lang_url',lang('URL'));
- $GLOBALS['phpgw']->template->set_var('url',$url);
- $GLOBALS['phpgw']->template->set_var('lang_timezone',lang('time zone offset'));
- $GLOBALS['phpgw']->template->set_var('timezone',$time_zone);
- $GLOBALS['phpgw']->template->set_var('lang_fax',lang('Business Fax'));
- $GLOBALS['phpgw']->template->set_var('fax',$fax);
- $GLOBALS['phpgw']->template->set_var('lang_wphone',lang('Business Phone'));
- $GLOBALS['phpgw']->template->set_var('wphone',$wphone);
- $GLOBALS['phpgw']->template->set_var('lang_pager',lang('Pager'));
- $GLOBALS['phpgw']->template->set_var('pager',$pager);
- $GLOBALS['phpgw']->template->set_var('lang_mphone',lang('Cell Phone'));
- $GLOBALS['phpgw']->template->set_var('mphone',$mphone);
- $GLOBALS['phpgw']->template->set_var('lang_msgphone',lang('Message Phone'));
- $GLOBALS['phpgw']->template->set_var('msgphone',$msgphone);
- $GLOBALS['phpgw']->template->set_var('lang_isdnphone',lang('ISDN Phone'));
- $GLOBALS['phpgw']->template->set_var('isdnphone',$isdnphone);
- $GLOBALS['phpgw']->template->set_var('lang_carphone',lang('Car Phone'));
- $GLOBALS['phpgw']->template->set_var('carphone',$carphone);
- $GLOBALS['phpgw']->template->set_var('lang_vidphone',lang('Video Phone'));
- $GLOBALS['phpgw']->template->set_var('vidphone',$vidphone);
+ $this->template->set_var('lang_company',lang('Company Name'));
+ $this->template->set_var('company',$company);
+ $this->template->set_var('lang_department',lang('Department'));
+ $this->template->set_var('department',$department);
+ $this->template->set_var('lang_title',lang('Title'));
+ $this->template->set_var('title',$title);
+ $this->template->set_var('lang_email',lang('Business Email'));
+ $this->template->set_var('email',$email);
+ $this->template->set_var('lang_email_type',lang('Business EMail Type'));
+ $this->template->set_var('email_type',$email_type);
+ $this->template->set_var('lang_url',lang('URL'));
+ $this->template->set_var('url',$url);
+ $this->template->set_var('lang_timezone',lang('time zone offset'));
+ $this->template->set_var('timezone',$time_zone);
+ $this->template->set_var('lang_fax',lang('Business Fax'));
+ $this->template->set_var('fax',$fax);
+ $this->template->set_var('lang_wphone',lang('Business Phone'));
+ $this->template->set_var('wphone',$wphone);
+ $this->template->set_var('lang_pager',lang('Pager'));
+ $this->template->set_var('pager',$pager);
+ $this->template->set_var('lang_mphone',lang('Cell Phone'));
+ $this->template->set_var('mphone',$mphone);
+ $this->template->set_var('lang_msgphone',lang('Message Phone'));
+ $this->template->set_var('msgphone',$msgphone);
+ $this->template->set_var('lang_isdnphone',lang('ISDN Phone'));
+ $this->template->set_var('isdnphone',$isdnphone);
+ $this->template->set_var('lang_carphone',lang('Car Phone'));
+ $this->template->set_var('carphone',$carphone);
+ $this->template->set_var('lang_vidphone',lang('Video Phone'));
+ $this->template->set_var('vidphone',$vidphone);
- $GLOBALS['phpgw']->template->set_var('lang_ophone',lang('Other Number'));
- $GLOBALS['phpgw']->template->set_var('ophone',$ophone);
- $GLOBALS['phpgw']->template->set_var('lang_bstreet',lang('Business Street'));
- $GLOBALS['phpgw']->template->set_var('bstreet',$bstreet);
- $GLOBALS['phpgw']->template->set_var('lang_address2',lang('Address Line 2'));
- $GLOBALS['phpgw']->template->set_var('address2',$address2);
- $GLOBALS['phpgw']->template->set_var('lang_address3',lang('Address Line 3'));
- $GLOBALS['phpgw']->template->set_var('address3',$address3);
- $GLOBALS['phpgw']->template->set_var('lang_bcity',lang('Business City'));
- $GLOBALS['phpgw']->template->set_var('bcity',$bcity);
- $GLOBALS['phpgw']->template->set_var('lang_bstate',lang('Business State'));
- $GLOBALS['phpgw']->template->set_var('bstate',$bstate);
- $GLOBALS['phpgw']->template->set_var('lang_bzip',lang('Business Zip Code'));
- $GLOBALS['phpgw']->template->set_var('bzip',$bzip);
- $GLOBALS['phpgw']->template->set_var('lang_bcountry',lang('Business Country'));
- $GLOBALS['phpgw']->template->set_var('bcountry',$bcountry);
- if($countrylist)
+ $this->template->set_var('lang_ophone',lang('Other Number'));
+ $this->template->set_var('ophone',$ophone);
+ $this->template->set_var('lang_bstreet',lang('Business Street'));
+ $this->template->set_var('bstreet',$bstreet);
+ $this->template->set_var('lang_address2',lang('Address Line 2'));
+ $this->template->set_var('address2',$address2);
+ $this->template->set_var('lang_address3',lang('Address Line 3'));
+ $this->template->set_var('address3',$address3);
+ $this->template->set_var('lang_bcity',lang('Business City'));
+ $this->template->set_var('bcity',$bcity);
+ $this->template->set_var('lang_bstate',lang('Business State'));
+ $this->template->set_var('bstate',$bstate);
+ $this->template->set_var('lang_bzip',lang('Business Zip Code'));
+ $this->template->set_var('bzip',$bzip);
+ $this->template->set_var('lang_bcountry',lang('Business Country'));
+ $this->template->set_var('bcountry',$bcountry);
+ if ($countrylist)
{
- $GLOBALS['phpgw']->template->set_var('bcountry',$GLOBALS['phpgw']->country->form_select($bcountry,'entry[bcountry]'));
+ $this->template->set_var('bcountry',$GLOBALS['phpgw']->country->form_select($bcountry,'entry[bcountry]'));
}
else
{
- $GLOBALS['phpgw']->template->set_var('bcountry',' ');
+ $this->template->set_var('bcountry',' ');
}
- $GLOBALS['phpgw']->template->set_var('lang_badrtype',lang('Address Type'));
- $GLOBALS['phpgw']->template->set_var('badrtype',$badrtype);
+ $this->template->set_var('lang_badrtype',lang('Address Type'));
+ $this->template->set_var('badrtype',$badrtype);
- $GLOBALS['phpgw']->template->set_var('lang_hphone',lang('Home Phone'));
- $GLOBALS['phpgw']->template->set_var('hphone',$hphone);
- $GLOBALS['phpgw']->template->set_var('lang_hemail',lang('Home Email'));
- $GLOBALS['phpgw']->template->set_var('hemail',$hemail);
- $GLOBALS['phpgw']->template->set_var('lang_hemail_type',lang('Home EMail Type'));
- $GLOBALS['phpgw']->template->set_var('hemail_type',$hemail_type);
- $GLOBALS['phpgw']->template->set_var('lang_hstreet',lang('Home Street'));
- $GLOBALS['phpgw']->template->set_var('hstreet',$hstreet);
- $GLOBALS['phpgw']->template->set_var('lang_hcity',lang('Home City'));
- $GLOBALS['phpgw']->template->set_var('hcity',$hcity);
- $GLOBALS['phpgw']->template->set_var('lang_hstate',lang('Home State'));
- $GLOBALS['phpgw']->template->set_var('hstate',$hstate);
- $GLOBALS['phpgw']->template->set_var('lang_hzip',lang('Home Zip Code'));
- $GLOBALS['phpgw']->template->set_var('hzip',$hzip);
- $GLOBALS['phpgw']->template->set_var('lang_hcountry',lang('Home Country'));
- if($countrylist)
+ $this->template->set_var('lang_hphone',lang('Home Phone'));
+ $this->template->set_var('hphone',$hphone);
+ $this->template->set_var('lang_hemail',lang('Home Email'));
+ $this->template->set_var('hemail',$hemail);
+ $this->template->set_var('lang_hemail_type',lang('Home EMail Type'));
+ $this->template->set_var('hemail_type',$hemail_type);
+ $this->template->set_var('lang_hstreet',lang('Home Street'));
+ $this->template->set_var('hstreet',$hstreet);
+ $this->template->set_var('lang_hcity',lang('Home City'));
+ $this->template->set_var('hcity',$hcity);
+ $this->template->set_var('lang_hstate',lang('Home State'));
+ $this->template->set_var('hstate',$hstate);
+ $this->template->set_var('lang_hzip',lang('Home Zip Code'));
+ $this->template->set_var('hzip',$hzip);
+ $this->template->set_var('lang_hcountry',lang('Home Country'));
+ if ($countrylist)
{
- $GLOBALS['phpgw']->template->set_var('hcountry',$GLOBALS['phpgw']->country->form_select($hcountry,'entry[hcountry]'));
+ $this->template->set_var('hcountry',$GLOBALS['phpgw']->country->form_select($hcountry,'entry[hcountry]'));
}
else
{
- $GLOBALS['phpgw']->template->set_var('hcountry',' ');
+ $this->template->set_var('hcountry',' ');
}
- $GLOBALS['phpgw']->template->set_var('lang_hadrtype',lang('Address Type'));
- $GLOBALS['phpgw']->template->set_var('hadrtype',$hadrtype);
+ $this->template->set_var('lang_hadrtype',lang('Address Type'));
+ $this->template->set_var('hadrtype',$hadrtype);
- $GLOBALS['phpgw']->template->set_var('create',$create);
- $GLOBALS['phpgw']->template->set_var('lang_notes',lang('notes'));
- $GLOBALS['phpgw']->template->set_var('notes',$notes);
- $GLOBALS['phpgw']->template->set_var('lang_label',lang('label'));
- $GLOBALS['phpgw']->template->set_var('label',$label);
- $GLOBALS['phpgw']->template->set_var('lang_pubkey',lang('Public Key'));
- $GLOBALS['phpgw']->template->set_var('pubkey',$pubkey);
- $GLOBALS['phpgw']->template->set_var('access_check',$access_check);
+ $this->template->set_var('create',$create);
+ $this->template->set_var('lang_notes',lang('notes'));
+ $this->template->set_var('notes',$notes);
+ $this->template->set_var('lang_label',lang('label'));
+ $this->template->set_var('label',$label);
+ $this->template->set_var('lang_pubkey',lang('Public Key'));
+ $this->template->set_var('pubkey',$pubkey);
+ $this->template->set_var('access_check',$access_check);
- $GLOBALS['phpgw']->template->set_var('lang_private',lang('Private'));
+ $this->template->set_var('lang_private',lang('Private'));
- $GLOBALS['phpgw']->template->set_var('lang_cats',lang('Category'));
- $GLOBALS['phpgw']->template->set_var('cats_link',$cats_link);
- if($customfields)
+ $this->template->set_var('lang_cats',lang('Category'));
+ $this->template->set_var('cats_link',$cats_link);
+ if ($customfields)
{
- $GLOBALS['phpgw']->template->set_var('lang_custom',lang('Custom Fields').':');
- $GLOBALS['phpgw']->template->set_var('custom',$custom);
+ $this->template->set_var('lang_custom',lang('Custom Fields').':');
+ $this->template->set_var('custom',$custom);
}
else
{
- $GLOBALS['phpgw']->template->set_var('lang_custom','');
- $GLOBALS['phpgw']->template->set_var('custom','');
+ $this->template->set_var('lang_custom','');
+ $this->template->set_var('custom','');
}
- $GLOBALS['phpgw']->template->set_var('th_bg', $GLOBALS['phpgw_info']['theme']['th_bg']);
- $GLOBALS['phpgw']->template->set_var('th_text', $GLOBALS['phpgw_info']['theme']['th_text']);
- $GLOBALS['phpgw']->template->set_var('row_on', $GLOBALS['phpgw_info']['theme']['row_on']);
- $GLOBALS['phpgw']->template->set_var('row_off', $GLOBALS['phpgw_info']['theme']['row_off']);
- $GLOBALS['phpgw']->template->set_var('row_text',$GLOBALS['phpgw_info']['theme']['row_text']);
+ $this->template->set_var('th_bg', $GLOBALS['phpgw_info']['theme']['th_bg']);
+ $this->template->set_var('th_text', $GLOBALS['phpgw_info']['theme']['th_text']);
+ $this->template->set_var('row_on', $GLOBALS['phpgw_info']['theme']['row_on']);
+ $this->template->set_var('row_off', $GLOBALS['phpgw_info']['theme']['row_off']);
+ $this->template->set_var('row_text',$GLOBALS['phpgw_info']['theme']['row_text']);
- $this->output .= $GLOBALS['phpgw']->template->fp('out','form');
+ $this->template->pfp('out','form');
} /* end form function */
}
?>
diff --git a/addressbook/inc/class.uifields.inc.php b/addressbook/inc/class.uifields.inc.php
index 2da9f8ad32..562ead7612 100644
--- a/addressbook/inc/class.uifields.inc.php
+++ b/addressbook/inc/class.uifields.inc.php
@@ -24,8 +24,8 @@
function uifields()
{
-// $GLOBALS['phpgw']->template = CreateObject('phpgwapi.Template',PHPGW_APP_TPL);
-// $GLOBALS['phpgw']->nextmatchs = CreateObject('phpgwapi.nextmatchs');
+ $GLOBALS['phpgw']->template = CreateObject('phpgwapi.Template',PHPGW_APP_TPL);
+ $GLOBALS['phpgw']->nextmatchs = CreateObject('phpgwapi.nextmatchs');
$this->config = CreateObject('phpgwapi.config','addressbook');
}
@@ -34,9 +34,9 @@
if(!$GLOBALS['phpgw']->acl->check('run',1,'admin'))
{
$GLOBALS['phpgw']->common->phpgw_header();
+ echo parse_navbar();
echo lang('access not permitted');
- $GLOBALS['phpgw_info']['flags']['nodisplay'] = True;
- exit;
+ $GLOBALS['phpgw']->common->phpgw_exit();
}
$GLOBALS['phpgw']->template->set_file(array(
@@ -80,6 +80,7 @@
$total_records = count($fields);
$GLOBALS['phpgw']->common->phpgw_header();
+ echo parse_navbar();
$GLOBALS['phpgw']->template->set_var('left',$GLOBALS['phpgw']->nextmatchs->left('/index.php',$start,$total_records,'menuaction=addressbook.uifields.index'));
$GLOBALS['phpgw']->template->set_var('right',$GLOBALS['phpgw']->nextmatchs->right('/index.php',$start,$total_records,'menuaction=addressbook.uifields.index'));
@@ -128,9 +129,9 @@
if(!$GLOBALS['phpgw']->acl->check('run',1,'admin'))
{
$GLOBALS['phpgw']->common->phpgw_header();
+ echo parse_navbar();
echo lang('access not permitted');
- $GLOBALS['phpgw_info']['flags']['nodisplay'] = True;
- exit;
+ $GLOBALS['phpgw']->common->phpgw_exit();
}
$field = stripslashes($GLOBALS['HTTP_POST_VARS']['field']);
@@ -166,6 +167,7 @@
}
$GLOBALS['phpgw']->common->phpgw_header();
+ echo parse_navbar();
if($errorcount)
{
@@ -204,9 +206,9 @@
if(!$GLOBALS['phpgw']->acl->check('run',1,'admin'))
{
$GLOBALS['phpgw']->common->phpgw_header();
+ echo parse_navbar();
echo lang('access not permitted');
- $GLOBALS['phpgw_info']['flags']['nodisplay'] = True;
- exit;
+ $GLOBALS['phpgw']->common->phpgw_exit();
}
$field = stripslashes($GLOBALS['HTTP_POST_VARS']['field'] ? $GLOBALS['HTTP_POST_VARS']['field'] : $GLOBALS['HTTP_GET_VARS']['field']);
@@ -245,6 +247,7 @@
}
$GLOBALS['phpgw']->common->phpgw_header();
+ echo parse_navbar();
if($errorcount)
{
@@ -296,9 +299,9 @@
if(!$GLOBALS['phpgw']->acl->check('run',1,'admin'))
{
$GLOBALS['phpgw']->common->phpgw_header();
+ echo parse_navbar();
echo lang('access not permitted');
- $GLOBALS['phpgw_info']['flags']['nodisplay'] = True;
- exit;
+ $GLOBALS['phpgw']->common->phpgw_exit();
}
$field = $GLOBALS['HTTP_POST_VARS']['field'] ? $GLOBALS['HTTP_POST_VARS']['field'] : $GLOBALS['HTTP_GET_VARS']['field'];
@@ -320,6 +323,7 @@
else
{
$GLOBALS['phpgw']->common->phpgw_header();
+ echo parse_navbar();
$hidden_vars = ' ' . "\n"
. ' ' . "\n"
diff --git a/addressbook/inc/class.uivcard.inc.php b/addressbook/inc/class.uivcard.inc.php
index 6d95c6c334..9b35f3dd69 100644
--- a/addressbook/inc/class.uivcard.inc.php
+++ b/addressbook/inc/class.uivcard.inc.php
@@ -26,7 +26,7 @@
'out' => True
);
- var $extrafields = array(
+ var $extrafields = array(
'ophone' => 'ophone',
'address2' => 'address2',
'address3' => 'address3'
@@ -43,13 +43,14 @@
function in()
{
- $action = $GLOBALS['HTTP_POST_VARS']['action'];
+ $action = $GLOBALS['HTTP_POST_VARS']['action'] ? $GLOBALS['HTTP_POST_VARS']['action'] : $GLOBALS['HTTP_GET_VARS']['action'];
$GLOBALS['phpgw']->common->phpgw_header();
+ echo parse_navbar();
echo '';
- if($action == 'GetFile')
+ if ($action == 'GetFile')
{
echo ' ' . lang('You must select a vcard. (*.vcf)') . ' ';
}
@@ -64,43 +65,39 @@
$this->template->set_var('group_option',$group_option);
$this->template->pparse('out','vcardin');
+
+ $GLOBALS['phpgw']->common->phpgw_footer();
}
function out()
{
- $ab_id = get_var('ab_id',array('GET','POST'));
- $nolname = get_var('nolname',array('GET','POST'));
- $nofname = get_var('nofname',array('GET','POST'));
+ $ab_id = $GLOBALS['HTTP_GET_VARS']['ab_id'] ? $GLOBALS['HTTP_GET_VARS']['ab_id'] : $GLOBALS['HTTP_POST_VARS']['ab_id'];
+ $nolname = $GLOBALS['HTTP_GET_VARS']['nolname'];
+ $nofname = $GLOBALS['HTTP_GET_VARS']['nofname'];
if($nolname || $nofname)
{
$GLOBALS['phpgw']->common->phpgw_header();
+ echo parse_navbar();
}
if(!$ab_id)
{
Header('Location: ' . $GLOBALS['phpgw']->link('/addressbook/index.php'));
- $GLOBALS['phpgw_info']['flags']['nodisplay'] = True;
- exit;
+ $GLOBALS['phpgw']->common->phpgw_exit();
}
// First, make sure they have permission to this entry
- $check = $this->bo->read_entry(array(
- 'id' => $ab_id,
- 'fields' => array(
- 'owner' => 'owner'
- )
- ));
+ $check = $this->bo->read_entry(array('id' => $ab_id, 'fields' => array('owner' => 'owner')));
$perms = $this->contacts->check_perms($this->contacts->grants[$check[0]['owner']],PHPGW_ACL_READ);
- if((!$perms) && ($check[0]['owner'] != $GLOBALS['phpgw_info']['user']['account_id']))
+ if ( (!$perms) && ($check[0]['owner'] != $GLOBALS['phpgw_info']['user']['account_id']) )
{
- Header('Location: ' . $GLOBALS['phpgw']->link('/index.php','menuaction=addressbook.uiaddressbook.get_list'));
- $GLOBALS['phpgw_info']['flags']['nodisplay'] = True;
- exit;
+ Header("Location: " . $GLOBALS['phpgw']->link('/index.php','menuaction=addressbook.uiaddressbook.get_list'));
+ $GLOBALS['phpgw']->common->phpgw_exit();
}
- $extrafields = array('address2' => 'address2');
+ $extrafields = array('address2' => 'address2');
$qfields = $this->contacts->stock_contact_fields + $extrafields;
$fieldlist = $this->bo->read_entry(array('id' => $ab_id, 'fields' => $qfields));
@@ -127,49 +124,50 @@
if($lastname == '')
{
/* Run away here. */
- Header('Location: ' . $GLOBALS['phpgw']->link('/index.php','menuaction=addressbook.uivcard.out&nolname=1&ab_id=' . $ab_id));
+ Header('Location: ' . $GLOBALS['phpgw']->link('/index.php',"menuaction=addressbook.uivcard.out&nolname=1&ab_id=$ab_id"));
}
if($firstname == '')
{
- Header('Location: ' . $GLOBALS['phpgw']->link('/index.php','menuaction=addressbook.uivcard.out&nofname=1&ab_id=' . $ab_id));
+ Header('Location: ' . $GLOBALS['phpgw']->link('/index.php',"menuaction=addressbook.uivcard.out&nofname=1&ab_id=$ab_id"));
}
if ($email)
{
$fn = explode('@',$email);
- $filename = sprintf('%s.vcf', $fn[0]);
+ $filename = sprintf("%s.vcf", $fn[0]);
}
elseif ($hemail)
{
$fn = explode('@',$hemail);
- $filename = sprintf('%s.vcf', $fn[0]);
+ $filename = sprintf("%s.vcf", $fn[0]);
}
else
{
$fn = strtolower($firstname);
- $filename = sprintf('%s.vcf', $fn);
+ $filename = sprintf("%s.vcf", $fn);
}
// set translation variable
$myexport = $this->vcard->export;
// check that each $fields exists in the export array and
// set a new array to equal the translation and original value
- while(list($name,$value) = each($fields))
+ while( list($name,$value) = each($fields) )
{
- if($myexport[$name] && ($value != ''))
+ if ($myexport[$name] && ($value != "") )
{
- //echo ' '.$name.'='.$fields[$name]."\n";
+ //echo ' '.$name."=".$fields[$name]."\n";
$buffer[$myexport[$name]] = $value;
}
}
// create a vcard from this translated array
- $entry = $this->vcard->out($buffer);
+ $entry = $this->vcard->out($buffer);
// print it using browser class for headers
// filename, mimetype, no length, default nocache True
$this->browser->content_header($filename,'text/x-vcard');
echo $entry;
- $GLOBALS['phpgw']->common->exit;
+ exit;
+ //$GLOBALS['phpgw']->common->exit;
} /* !nolname && !nofname */
if($nofname)
@@ -177,7 +175,8 @@
echo '';
echo lang("This person's first name was not in the address book.") .' ';
echo lang('Vcards require a first name entry.') . ' ';
- echo '' . lang('OK') . ' ';
+ echo '' . lang('OK') . ' ';
echo ' ';
}
@@ -186,9 +185,15 @@
echo '';
echo lang("This person's last name was not in the address book.") . ' ';
echo lang('Vcards require a last name entry.') . ' ';
- echo '' . lang('OK') . ' ';
+ echo '' . lang('OK') . ' ';
echo ' ';
}
+
+ if($nolname || $nofname)
+ {
+ //$GLOBALS['phpgw']->common->phpgw_footer();
+ }
}
}
?>
diff --git a/addressbook/inc/functions.inc.php b/addressbook/inc/functions.inc.php
index cba49654ef..4dcc53672f 100755
--- a/addressbook/inc/functions.inc.php
+++ b/addressbook/inc/functions.inc.php
@@ -43,8 +43,6 @@
/* Return a select form element with the categories option dialog in it */
function cat_option($cat_id='',$notall=False,$java=True,$multiple=False)
{
- global $phpgw;
-
if ($java)
{
$jselect = ' onChange="this.form.submit();"';
@@ -62,7 +60,7 @@
}
/* Get global and app-specific category listings */
- $cats_link .= $phpgw->categories->formatted_list('select','all',$cat_id,True);
+ $cats_link .= $GLOBALS['phpgw']->categories->formated_list('select','all',$cat_id,True);
$cats_link .= ''."\n";
return $cats_link;
}
@@ -134,12 +132,10 @@
function read_custom_fields()
{
- global $phpgw_info;
-
$i = 0; $j = 0;
$fields = array();
- @reset($phpgw_info['user']['preferences']['addressbook']);
- while (list($col,$descr) = @each($phpgw_info['user']['preferences']['addressbook']))
+ @reset($GLOBALS['phpgw_info']['user']['preferences']['addressbook']);
+ while (list($col,$descr) = @each($GLOBALS['phpgw_info']['user']['preferences']['addressbook']))
{
if ( substr($col,0,6) == 'extra_' )
{
@@ -166,17 +162,15 @@
function save_custom_field($old='',$new='')
{
- global $phpgw,$phpgw_info;
-
- $phpgw->preferences->read_repository($phpgw_info['user']['account_id']);
+ $GLOBALS['phpgw']->preferences->read_repository($GLOBALS['phpgw_info']['user']['account_id']);
if ($old)
{
- $phpgw->preferences->delete("addressbook","extra_".$old);
+ $GLOBALS['phpgw']->preferences->delete("addressbook","extra_".$old);
}
if($new)
{
- $phpgw->preferences->add("addressbook","extra_".$new);
+ $GLOBALS['phpgw']->preferences->add("addressbook","extra_".$new);
}
- $phpgw->preferences->save_repository(1);
+ $GLOBALS['phpgw']->preferences->save_repository(1);
}
?>
diff --git a/addressbook/inc/hook_help.inc.php b/addressbook/inc/hook_help.inc.php
deleted file mode 100644
index 8191bc9918..0000000000
--- a/addressbook/inc/hook_help.inc.php
+++ /dev/null
@@ -1,41 +0,0 @@
-help->set_params(array('app_name' => 'addressbook',
- 'title' => lang('addressbook'),
- 'app_version' => $setup_info['addressbook']['version']));
-
- $GLOBALS['phpgw']->help->data[] = array
- (
- 'text' => lang('owerview'),
- 'link' => $GLOBALS['phpgw']->help->check_help_file('overview.php'),
- 'lang_link_statustext' => lang('owerview')
- );
-
- $GLOBALS['phpgw']->help->data[] = array
- (
- 'text' => lang('list'),
- 'link' => $GLOBALS['phpgw']->help->check_help_file('list.php'),
- 'lang_link_statustext' => lang('list')
- );
-
- $GLOBALS['phpgw']->help->data[] = array
- (
- 'text' => lang('add'),
- 'link' => $GLOBALS['phpgw']->help->check_help_file('add.php'),
- 'lang_link_statustext' => lang('add')
- );
-
- $GLOBALS['phpgw']->help->draw();
-?>
diff --git a/addressbook/inc/hook_home.inc.php b/addressbook/inc/hook_home.inc.php
index 4e8471b86a..da604e7ddf 100644
--- a/addressbook/inc/hook_home.inc.php
+++ b/addressbook/inc/hook_home.inc.php
@@ -1,55 +1,83 @@
\n";
- $GLOBALS['phpgw_info']['flags']['nodisplay'] = True;
- exit;
+ $GLOBALS['phpgw']->common->phpgw_exit();
}
unset($d1);
if ($GLOBALS['phpgw_info']['user']['apps']['addressbook']
&& $GLOBALS['phpgw_info']['user']['preferences']['addressbook']['mainscreen_showbirthdays'])
{
+ echo "\n\n";
+
$c = CreateObject('phpgwapi.contacts');
- $qfields = array
- (
+ $qfields = array(
'n_given' => 'n_given',
'n_family' => 'n_family',
'bday' => 'bday'
);
$now = time() - ((60 * 60) * intval($GLOBALS['phpgw_info']['user']['preferences']['common']['tz_offset']));
$today = $GLOBALS['phpgw']->common->show_date($now,'n/d/');
-
+
$bdays = $c->read(0,15,$qfields,$today,'tid=n','','',$GLOBALS['phpgw_info']['user']['account_id']);
+
+ $title = ''.lang('Birthdays').' ';
+ $portalbox = CreateObject('phpgwapi.listbox',
+ Array(
+ 'title' => $title,
+ 'primary' => $GLOBALS['phpgw_info']['theme']['navbar_bg'],
+ 'secondary' => $GLOBALS['phpgw_info']['theme']['navbar_bg'],
+ 'tertiary' => $GLOBALS['phpgw_info']['theme']['navbar_bg'],
+ 'width' => '100%',
+ 'outerborderwidth' => '0',
+ 'header_background_image' => $GLOBALS['phpgw']->common->image('phpgwapi/templates/default','bg_filler')
+ )
+ );
$app_id = $GLOBALS['phpgw']->applications->name2id('addressbook');
$GLOBALS['portal_order'][] = $app_id;
+ $var = Array(
+ 'up' => Array('url' => '/set_box.php', 'app' => $app_id),
+ 'down' => Array('url' => '/set_box.php', 'app' => $app_id),
+ 'close' => Array('url' => '/set_box.php', 'app' => $app_id),
+ 'question' => Array('url' => '/set_box.php', 'app' => $app_id),
+ 'edit' => Array('url' => '/set_box.php', 'app' => $app_id)
+ );
+
+ while(list($key,$value) = each($var))
+ {
+ $portalbox->set_controls($key,$value);
+ }
+
+ $portalbox->data = Array();
- $GLOBALS['phpgw']->portalbox->set_params(array('app_id' => $app_id,
- 'title' => lang('addressbook')));
while(list($key,$val) = @each($bdays))
{
if (substr($val['bday'],0,strlen($today)) == $today)
{
- $GLOBALS['phpgw']->portalbox->data[] = array
- (
- 'text' => lang("Today is %1's birthday!", $val['n_given'] . ' ' . $val['n_family']),
- 'link' => $GLOBALS['phpgw']->link('/index.php','menuaction=addressbook.uiaddressbook.view&ab_id=' . $val['id']),
- 'lang_link_statustext' => lang('show contact')
+ $portalbox->data[] = array(
+ 'text' => lang("Today is %1's birthday!", $val['n_given'] . ' ' . $val['n_family']),
+ 'link' => $GLOBALS['phpgw']->link('/index.php','menuaction=addressbook.uiaddressbook.view&ab_id=' . $val['id'])
);
}
+// $tmp = ''
+// . $val['n_given'] . ' ' . $val['n_family'] . ' ';
+// echo '' . lang("Today is %1's birthday!", $tmp) . ' ' . "\n";
}
$tomorrow = $GLOBALS['phpgw']->common->show_date($now + 86400,'n/d/');
@@ -60,14 +88,21 @@
{
if (substr($val['bday'],0,strlen($tomorrow)) == $tomorrow)
{
- $GLOBALS['phpgw']->portalbox->data[] = array
- (
- 'text' => lang("Tomorrow is %1's birthday.", $val['n_given'] . ' ' . $val['n_family']),
- 'link' => $GLOBALS['phpgw']->link('/index.php','menuaction=addressbook.uiaddressbook.view&ab_id='.$val['id']),
- 'lang_link_statustext' => lang('show contact')
+ $portalbox->data[] = array(
+ 'text' => lang("Tomorrow is %1's birthday.",$val['n_given'] . ' ' . $val['n_family']),
+ 'link' => $GLOBALS['phpgw']->link('/index.php','menuaction=addressbook.uiaddressbook.view&ab_id='.$val['id'])
);
}
+// $tmp = ''
+// . $val['n_given'] . ' ' . $val["n_family"] . ' ';
+// echo '' . lang("Tomorrow is %1's birthday.", $tmp) . ' ' . "\n";
}
- $GLOBALS['phpgw']->portalbox->draw();
+ if(count($portalbox->data))
+ {
+ echo $portalbox->draw();
+ }
+ unset($portalbox);
+ echo "\n\n";
}
?>
diff --git a/addressbook/inc/hook_manual.inc.php b/addressbook/inc/hook_manual.inc.php
new file mode 100755
index 0000000000..365e315b61
--- /dev/null
+++ b/addressbook/inc/hook_manual.inc.php
@@ -0,0 +1,19 @@
+ *
+ * -------------------------------------------- *
+ * This program is free software; you can redistribute it and/or modify it *
+ * under the terms of the GNU General Public License as published by the *
+ * Free Software Foundation; either version 2 of the License, or (at your *
+ * option) any later version. *
+ \**************************************************************************/
+
+ /* $Id$ */
+
+// Only Modify the $file variable.....
+ $file = Array();
+//Do not modify below this line
+ display_manual_section($appname,$file);
+?>
diff --git a/addressbook/inc/hook_notifywindow.inc.php b/addressbook/inc/hook_notifywindow.inc.php
index eb4f0a4bc2..7e49f68309 100644
--- a/addressbook/inc/hook_notifywindow.inc.php
+++ b/addressbook/inc/hook_notifywindow.inc.php
@@ -15,8 +15,7 @@
if($d1 == 'htt' || $d1 == 'ftp' )
{
echo "Failed attempt to break in via an old Security Hole! \n";
- $GLOBALS['phpgw_info']['flags']['nodisplay'] = True;
- exit;
+ $GLOBALS['phpgw']->common->phpgw_exit();
}
unset($d1);
diff --git a/addressbook/index.php b/addressbook/index.php
index 47c69e63e6..62e54f74d3 100755
--- a/addressbook/index.php
+++ b/addressbook/index.php
@@ -1,10 +1,10 @@
*
- * and Miles Lott *
+ * -------------------------------------------- *
+ * Funding for this program was provided by http://www.checkwithmom.com *
* -------------------------------------------- *
* This program is free software; you can redistribute it and/or modify it *
* under the terms of the GNU General Public License as published by the *
@@ -17,10 +17,14 @@
$GLOBALS['phpgw_info'] = array();
$GLOBALS['phpgw_info']['flags'] = array(
- 'currentapp' => 'addressbook'
+ 'currentapp' => 'addressbook',
+ 'noheader' => True,
+ 'nonavbar' => True
);
include('../header.inc.php');
$obj = CreateObject('addressbook.uiaddressbook');
$obj->index();
+
+ $GLOBALS['phpgw']->common->phpgw_footer();
?>
diff --git a/addressbook/setup/phpgw_de.lang b/addressbook/setup/phpgw_de.lang
index 641c9a515a..5c465c8b80 100644
--- a/addressbook/setup/phpgw_de.lang
+++ b/addressbook/setup/phpgw_de.lang
@@ -1,15 +1,19 @@
+%1 records imported addressbook de %1 Datensätze importiert
+%1 records read (not yet imported, you may go %2back%3 and uncheck test import) addressbook de %1 Datensätze gelesen (noch nicht importiert, sie können %2zurück%3 gehen und Test-Import auschalten)
no conversion type <none> could be located. please choose a conversion type from the list addressbook de Kein Übersetzungstyp <none> konnte gefunden werden. Bitte wählen Sie einen Übersetzungstype aus der Liste
-no conversion type could be located. please choose a conversion type from the list addressbook de Kein Übersetzungstyp <none> konnte gefunden werden. Bitte wählen Sie einen Übersetzungstype aus der Liste
+@-eval() is only availible to admins!!! addressbook de @-eval() ist nur verfügbar für Administratoren!!!
+add a single entry by passing the fields. addressbook de Hinzufügen eines einzelnen Eintrags durch Übergeben der Felder.
add custom field addressbook de Benutzerdefiniertes Feld hinzufügen
address book common de Adressbuch
+address book - vcard in addressbook de Adressbuch - VCard in
address book - view addressbook de Adressbuch - Anzeigen
address line 2 addressbook de Adreßzeile 2
address line 3 addressbook de Adreßzeile 3
address type addressbook de Adreßtyp
addressbook common de Adressbuch
addressbook preferences addressbook de Adressbuch Einstellungen
+addressbook-fieldname addressbook de Adressbuch Feldname
addvcard addressbook de VCard hinzufügen
-alphabet addressbook de a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z
alt. csv import addressbook de Alt. CSV Import
are you sure you want to delete this field? addressbook de Sind Sie sicher, dass sie dieses Feld löschen wollen?
bbs phone addressbook de BBS
@@ -35,27 +39,32 @@ company name common de Firmenname
contact common de Kontakt
contact application admin de Kontakt Anwendung
contact settings admin de Kontakt Einstellungen
+copied by %1, from record #%2. addressbook de Kopiert von %1, vom Datensatz Nr. %2.
country common de Land
+csv-fieldname addressbook de CSV-Feldname
+csv-filename addressbook de CSV-Dateiname
custom addressbook de Benutzerdefiniert
custom fields addressbook de Benutzerdefinierte Felder
-debug output in browser addressbook de Ausgaben zur Fehlersuche im Webbrowser
+debug output in browser addressbook de Debugausgaben in Browser
default filter addressbook de Standardfilter
+delete a single entry by passing the id. addressbook de Löscht einen einzelnen Eintrag durch Übergabe seiner Id.
department common de Abteilung
domestic addressbook de Wohnung
-download export file (uncheck to debug output in browser) addressbook de Exportdatei herunterladen (nicht auswählen um eine Test-Ausgabe im Browser zu bekommen)
+download addressbook de Herunterladen
edit custom field addressbook de Benutzerdefiniertes Feld bearbeiten
edit custom fields admin de Benutzerdefinierte Felder bearbeiten
-enable remote search admin de Fern-Suche zulassen
-enter the path to the export file here addressbook de Geben Sie hier den Pfad zur exportierent Datei an
export contacts addressbook de Kontakte exportieren
export file name addressbook de Dateiname zum Exportieren
+export from addressbook addressbook de Export vom Addressbuch
extra addressbook de Extra
fax addressbook de Telefax
fax number common de Telefaxnummer
-field name addressbook de Feldname
field %1 has been added ! addressbook de Feld %1 wurde hinzugefügt !
+field %1 has been updated ! addressbook de Feld %1 wurde aktualisiert !
+field name addressbook de Feldname
fields addressbook de Felder
fields to show in address list addressbook de Felder, die in der Adressliste angezeigt werden sollen
+fieldseparator addressbook de Feldtrenner
full name addressbook de vollständiger Name
geo addressbook de GEO
grant addressbook access common de Berechtigungen
@@ -68,10 +77,12 @@ home phone addressbook de Tel privat
home state addressbook de Land (priv)
home street addressbook de Straße (priv)
home zip code addressbook de PLZ (priv)
+import addressbook de Import
import contacts addressbook de Kontakte importieren
+import csv-file into addressbook addressbook de Import CSV-Datei ins Addressbuch
import file addressbook de Datei importieren
+import from ldif, csv, or vcard addressbook de Import von LDIF, CSV oder VCard
import from outlook addressbook de Aus Outlook importieren
-in netscape, open the addressbook and select export from the file menu. the file exported will be in ldif format.or, in outlook, select your contacts folder, select import and export... from addressbook de
international addressbook de International
isdn phone addressbook de ISDN Tel.
label addressbook de Adreßetikett
@@ -79,15 +90,16 @@ ldap context for contacts admin de LDAP Kontext f
ldap host for contacts admin de LDAP Host für Kontakte
ldap root dn for contacts admin de LDAP rootdn für Kontakte
ldap root pw for contacts admin de LDAP Paswort für Kontakte
+ldif addressbook de LDIF
line 2 addressbook de Zeile 2
-mark records as private addressbook de Einträge als privat markieren
message phone addressbook de Anrufbeantworter
middle name addressbook de Zweiter Vorname
mobile addressbook de Mobil
mobile phone addressbook de Mobil-Telefon
modem phone addressbook de Modem
no vcard addressbook de Keine VCard
-none addressbook de keine
+number of records to read (<=200) addressbook de Nummer der einzulesenden Datensätze (<= 200)
+on addressbook de an
other addressbook de Andere
other number addressbook de andere Nr.
other phone addressbook de Anderes Telefon
@@ -96,182 +108,43 @@ parcel addressbook de Lieferadresse
personal addressbook de Persönlich
phone number common de Telefon
phone numbers common de Telefonnummern
+please enter a name for that field ! addressbook de Bitte geben sie einen Namen für das Feld an !
+please select addressbook de Bitte auswählen
postal common de Postanschrift
pref addressbook de pref
prefix addressbook de Prefix
public key addressbook de öffentlicher Schlüssel
+read a list of entries. addressbook de Liest eine Liste von Einträgen.
+read a single entry by passing the id and fieldlist. addressbook de Liest einen einzelnen Eintrag über seine Id und Feldliste.
+read this list of methods. addressbook de Liest diese Liste der Methoden.
record access addressbook de Zugriffsrechte
record owner addressbook de Datensatz Eigentümer
retrieve contacts admin de Kontakte laden
-select the type of conversion addressbook de Art der Umsetzung auswählen
+select addressbook de Auswählen
select where you want to store admin de Auswählen wo Sie speichern wollen
show birthday reminders on main screen addressbook de Geburtstags-Mahner auf der Startseite anzeigen
+startrecord addressbook de Startdatensatz
state common de Land
street common de Straße
successfully imported %1 records into your addressbook. addressbook de %1 Kontakte wurden erfolgreich in ihr Adressbuch importiert
suffix addressbook de Zusatz
-the file menu and export your contacts into a comma separated text (csv) file.
or, in palm desktop 4.0 or greater, visit your addressbook and select export from the file menu. the file exported will be in vcard format.
addressbook de
+test import (show importable records only in browser) addressbook de Test-Import (zeigt importierbare Datensätze nur im Browser an)
+that field name has been used already ! addressbook de Dieser Feldname wird bereits benutzt !
this person's first name was not in the address book. addressbook de Der Vorname dieser Person ist nicht im Adressbuch.
+this person's last name was not in the address book. addressbook de Der Nachname dieser Person ist nicht im Adressbuch.
today is %1's birthday! common de Heute ist der Geburtstag von %1!
tomorrow is %1's birthday. common de Morgen ist der Geburtstag von %1.
+translation addressbook de Übersetzung
+update a single entry by passing the fields. addressbook de Aktualisiert einen einzelnen Eintrag durch Übergabe seiner Felder.
+use country list addressbook de Länderliste benutzen
vcard common de VCard
vcards require a first name entry. addressbook de VCards benötigen einen Vornamen.
+vcards require a last name entry. addressbook de VCards benötigen einen Nachnamen.
video phone addressbook de Bildtelefon
voice phone addressbook de Telefon
warning!! ldap is valid only if you are not using contacts for accounts storage! admin de WARNUNG!! LDAP darf nur verwendet werden, wenn sie die Benutzerkonten nicht im Adressbuch speichern!
work phone addressbook de Tel dienstl.
+you appear to be running addressbook de Sie benutzen gerade einen
+you must select a vcard. (*.vcf) addressbook de Sie müssen eine VCard auswählen (*.vcf)
+you must select at least 1 column to display addressbook de Sie müssen mindestens eine Spalte zum Anzeigen auswählen
zip code common de PLZ
-
-Fatal error : Call to undefined function: phpgw_exit() in /www/drock/html/cvs_phpgroupware/developer_tools/inc/class.uilangfile.inc.php on line 566
-
-
-
-
-
-
-
-
-
-
-
-
- phpGroupWare@CVS@granit
-
-
-
-
-
-
-
-
-
-
-
-
- Ralf Becker <ralf> - Saturday 01.03.2003
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
- Powered by phpGroupWare Version 0.9.15.008
-
-
-
-
-
diff --git a/addressbook/setup/phpgw_en.lang b/addressbook/setup/phpgw_en.lang
index 87f3f9d1b7..efe0872b3b 100644
--- a/addressbook/setup/phpgw_en.lang
+++ b/addressbook/setup/phpgw_en.lang
@@ -1,6 +1,7 @@
%1 records imported addressbook en %1 records imported
%1 records read (not yet imported, you may go %2back%3 and uncheck test import) addressbook en %1 records read (not yet imported, you may go %2back%3 and uncheck Test Import)
no conversion type <none> could be located. please choose a conversion type from the list addressbook en No conversion type <none> could be located. Please choose a conversion type from the list
+@-eval() is only availible to admins!!! addressbook en @-eval() is only availible to admins!!!
add a single entry by passing the fields. addressbook en Add a single entry by passing the fields.
add custom field addressbook en Add Custom Field
address book common en Address Book
@@ -13,7 +14,6 @@ addressbook common en Addressbook
addressbook preferences addressbook en Addressbook preferences
addressbook-fieldname addressbook en Addressbook-Fieldname
addvcard addressbook en Add VCard
-alphabet addressbook en a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z
alt. csv import addressbook en Alt. CSV Import
are you sure you want to delete this field? addressbook en Are you sure you want to delete this field?
bbs phone addressbook en BBS Phone
@@ -39,6 +39,7 @@ company name common en Company Name
contact common en Contact
contact application admin en Contact application
contact settings admin en Contact Settings
+copied by %1, from record #%2. addressbook en Copied by %1, from record #%2.
country common en Country
csv-fieldname addressbook en CSV-Fieldname
csv-filename addressbook en CSV-Filename
@@ -50,10 +51,8 @@ delete a single entry by passing the id. addressbook en Delete a single entry by
department common en Department
domestic addressbook en Domestic
download addressbook en Download
-download export file (uncheck to debug output in browser) addressbook en Download export file (Uncheck to debug output in browser)
edit custom field addressbook en Edit Custom Field
edit custom fields admin en Edit Custom Fields
-enter the path to the export file here addressbook en Enter the path to the export file here
export contacts addressbook en Export Contacts
export file name addressbook en Export file name
export from addressbook addressbook en Export from Addressbook
@@ -67,7 +66,6 @@ fields to show in address list addressbook en Fields to show in address list
fieldseparator addressbook en Fieldseparator
full name addressbook en Full Name
geo addressbook en GEO
-go addressbook en Go
grant addressbook access common en Grant Addressbook Access
home address type addressbook en Home Address Type
home city addressbook en Home City
@@ -84,7 +82,6 @@ import csv-file into addressbook addressbook en Import CSV-File into Addressbook
import file addressbook en Import File
import from ldif, csv, or vcard addressbook en Import from LDIF, CSV, or VCard
import from outlook addressbook en Import from Outlook
-In Netscape, open the Addressbook and select Export from the File menu. The file exported will be in LDIF format.Or, in Outlook, select your Contacts folder, select Import and Export... from addressbook en In Netscape, open the Addressbook and select Export from the File menu. The file exported will be in LDIF format.
Or, in Outlook, select your Contacts folder, select Import and Export... from
international addressbook en International
isdn phone addressbook en ISDN Phone
label addressbook en Label
@@ -94,7 +91,6 @@ ldap root dn for contacts admin en LDAP root dn for contacts
ldap root pw for contacts admin en LDAP root pw for contacts
ldif addressbook en LDIF
line 2 addressbook en Line 2
-mark records as private addressbook en Mark records as private
message phone addressbook en Message Phone
middle name addressbook en Middle Name
mobile addressbook en Mobile
@@ -104,7 +100,6 @@ no vcard addressbook en No VCard
number of records to read (<=200) addressbook en Number of records to read (<=200)
other number addressbook en Other Number
other phone addressbook en Other Phone
-owerview addressbook en owerview
pager common en Pager
parcel addressbook en Parcel
phone number common en Phone Number
@@ -118,24 +113,21 @@ read a list of entries. addressbook en Read a list of entries.
read a single entry by passing the id and fieldlist. addressbook en Read a single entry by passing the id and fieldlist.
record access addressbook en Record Access
record owner addressbook en Record owner
-remote search addressbook en Remote Search
retrieve contacts admin en retrieve contacts
-select the type of conversion addressbook en Select the type of conversion
select where you want to store admin en Select where you want to store
show birthday reminders on main screen addressbook en Show birthday reminders on main screen
-show contact addressbook en show contact
startrecord addressbook en Startrecord
state common en State
street common en Street
suffix addressbook en Suffix
test import (show importable records only in browser) addressbook en Test Import (show importable records only in browser)
that field name has been used already ! addressbook en That field name has been used already !
-the File menu and export your contacts into a comma separated text (CSV) file.
Or, in Palm Desktop 4.0 or greater, visit your addressbook and select Export from the File menu. The file exported will be in VCard format.
addressbook en the File menu and export your contacts into a comma separated text (CSV) file.
Or, in Palm Desktop 4.0 or greater, visit your addressbook and select Export from the File menu. The file exported will be in VCard format.
this person's first name was not in the address book. addressbook en This person's first name was not in the address book.
this person's last name was not in the address book. addressbook en This person's last name was not in the address book.
today is %1's birthday! common en Today is %1's birthday!
tomorrow is %1's birthday. common en Tomorrow is %1's birthday.
update a single entry by passing the fields. addressbook en Update a single entry by passing the fields.
+use country list addressbook en Use Country List
vcard common en VCard
vcards require a first name entry. addressbook en VCards require a first name entry.
vcards require a last name entry. addressbook en Vcards require a last name entry.
diff --git a/addressbook/setup/phpgw_es.lang b/addressbook/setup/phpgw_es.lang
index 0eda483ee5..e29a881fd7 100644
--- a/addressbook/setup/phpgw_es.lang
+++ b/addressbook/setup/phpgw_es.lang
@@ -37,16 +37,13 @@ country common es Pais
csv-fieldname addressbook es Campo CSV
csv-filename addressbook es Archivo CSV
custom fields addressbook es Campos Personalizados
-debug output in browser addressbook es Visualizar depuracion
default filter preferences es Filtro por Defecto
department common es Departmento
domestic common es Nacional
download addressbook es Descargar Archivo
-download export file (uncheck to debug output in browser) addressbook es Descargar archivo exportado
edit custom field admin es Editar Campo Personalizado
edit custom fields admin es Editar Campos Personalizados
e-mail addressbook es E-Mail
-enter the path to the export file here addressbook es Ingrese la ruta al archivo exportado aqui
export contacts addressbook es Exportar Contactos
export file name addressbook es Nombre del Archivo a Exportar
export from addressbook addressbook es Exportar de la Libreta de Direcciones
@@ -76,8 +73,6 @@ import file addressbook es Importar Archivo
import from ldif, csv, or vcard addressbook es Importar desde LDIF, CSV o VCard
import from netscape addressbook es Importar desde Netscape
import from outlook addressbook es Importar desde Outlook
-In Netscape, open the Addressbook and select Export from the File menu. The file exported will be in LDIF format.
Or, in Outlook, select your Contacts folder, select Import and Export... from addressbook es
-the File menu and export your contacts into a comma separated text (CSV) file.
Or, in Palm Desktop 4.0 or greater, visit your addressbook and select Export from the File menu. The file exported will be in VCard format.
addressbook es Desde Outlook, seleccione su carpeta de contactos, seleccione Importar y Exportar del menu Archivo y exporte sus contactos en un archivo de Texto separado por comas (CSV).
international common es Internacional
isdn phone addressbook es Telefono ISDN
label addressbook es Etiqueta
@@ -87,14 +82,12 @@ ldap host for contacts admin es Host LDAP para contacts
ldap root dn for contacts admin es Raiz LDAP dn para contactos
ldap root pw for contacts admin es Raiz LDAP pw para contactos
line 2 addressbook es Linea 2
-mark records as private addressbook es Marcar registros como Privados
message phone addressbook es Telefono de Mensajes
middle name addressbook es Segundo Nombre
mobile addressbook es Tel.Celular
mobile phone addressbook es Telefono Movil
modem phone addressbook es Telefono Modem
no vcard common es Sin VCard
-none addressbook es Ninguno
number of records to read (<=200) addressbook es Registros a leer (menos de 200)
other number addressbook es Otro Numero
other phone addressbook es Otro Telefono
@@ -112,7 +105,6 @@ record access addressbook es Acceso al registro
record owner addressbook es Dueño del registro
records read (not yet imported, you may go back and uncheck test import) addressbook es registros leidos (aun no importados, usted puede volver y desmarcar Testear)
retrieve contacts admin es Recuperar Contactos
-select the type of conversion addressbook es Seleccione el tipo de conversion
select where you want to store admin es Seleccione donde desea almacenar
show birthday reminders on main screen addressbook es Mostrar recordatorios de Cumpleaños en la Pantalla Principal
startrecord addressbook es Registro Inicial
diff --git a/addressbook/setup/phpgw_fr.lang b/addressbook/setup/phpgw_fr.lang
index 71ad3e2691..f5e03e30db 100644
--- a/addressbook/setup/phpgw_fr.lang
+++ b/addressbook/setup/phpgw_fr.lang
@@ -1,6 +1,7 @@
%1 records imported addressbook fr %1 enregistrements importés
-%1 records read (not yet imported, you may go %2back%3 and uncheck test import) addressbook fr %1 enregistrements lus (pas encore importés, vous pouvez revenir %2en arrière%3 et décocher Tester l'import)
+%1 records read (not yet imported, you may go %2back%3 and uncheck test import) addressbook fr %1 enregistrements lus (pas
no conversion type <none> could be located. please choose a conversion type from the list addressbook fr Aucun type de conversion <aucun> n'a pu être trouvé. SVP choisissez un type de conversion depuis la liste
+@-eval() is only availible to admins!!! addressbook fr @-eval() est disponible uniquement pour les administrateurs!!!
add a single entry by passing the fields. addressbook fr Ajouter une seule entrée en passant les champs.
add custom field addressbook fr Ajouter champ personnalisé
address book common fr Carnet d'adresses
@@ -13,7 +14,6 @@ addressbook common fr Carnet d'adresses
addressbook preferences addressbook fr Préférences du carnet d'adresses
addressbook-fieldname addressbook fr Carnet d'adresses-nomdechamp
addvcard addressbook fr Ajouter VCard
-alphabet addressbook fr a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z
alt. csv import addressbook fr Import Alt. CSV
are you sure you want to delete this field? addressbook fr Etes-vous sûr de vouloir effacer ce champ?
bbs phone addressbook fr Téléphone BBS
@@ -39,6 +39,7 @@ company name common fr Nom de la soci
contact common fr Contact
contact application admin fr Application contact
contact settings admin fr Paramètres du contact
+copied by %1, from record #%2. addressbook fr Copié par %1, depuis l'enregistrement #%2.
country common fr Pays
csv-fieldname addressbook fr CSV-Nomdechamp
csv-filename addressbook fr CSV-Nomdefichier
@@ -50,10 +51,8 @@ delete a single entry by passing the id. addressbook fr Effacer une seule entr
department common fr Département
domestic addressbook fr Domestique
download addressbook fr Downloader
-download export file (uncheck to debug output in browser) addressbook fr Downloader le fichier d'export (Décocher pour débogger la sortie dans le navigateur)
edit custom field addressbook fr Editer le champ personnalisé
edit custom fields admin fr Editer les champs personnalisés
-enter the path to the export file here addressbook fr Entrez le chemin vers le fichier d'export ici
export contacts addressbook fr Exporter les contacts
export file name addressbook fr Nom du fichier d'export
export from addressbook addressbook fr Exporter depuis le carnet d'adresses
@@ -67,7 +66,6 @@ fields to show in address list addressbook fr Champs
fieldseparator addressbook fr Séparateur de champ
full name addressbook fr Nom complet
geo addressbook fr GEO
-go addressbook fr Allez
grant addressbook access common fr Régler les droits d'accès au carnet d'adresses
home address type addressbook fr Type d'adresse (domicile)
home city addressbook fr Ville (domicile)
@@ -84,7 +82,6 @@ import csv-file into addressbook addressbook fr Importer le fichier CSV dans le
import file addressbook fr Importer le fichier
import from ldif, csv, or vcard addressbook fr Importer depuis LDIF, CSV ou VCard
import from outlook addressbook fr Importer depuis Outlook
-In Netscape, open the Addressbook and select Export from the File menu. The file exported will be in LDIF format.Or, in Outlook, select your Contacts folder, select Import and Export... from addressbook fr Dans Netscape, ouvrez le carnet d'adresses et choisissez Exporter dans le menu Fichier . Le fichier exporté sera dans le format LDIF.
Ou, dans Outlook, choisissez votre dossier Contacts, choisissez Importer et Exporter... depuis
international addressbook fr International
isdn phone addressbook fr Téléphone RNIS
label addressbook fr Label
@@ -94,7 +91,6 @@ ldap root dn for contacts admin fr Racine LDAP dn pour les contacts
ldap root pw for contacts admin fr Racine LDAP pw pour les contacts
ldif addressbook fr LDIF
line 2 addressbook fr Ligne 2
-mark records as private addressbook fr Marquer les enregistrements comme privés
message phone addressbook fr Téléphone de message
middle name addressbook fr Deuxième prénom
mobile addressbook fr Portable
@@ -104,7 +100,6 @@ no vcard addressbook fr Pas de VCard
number of records to read (<=200) addressbook fr Nombre d'enregistrements à lire (<=200)
other number addressbook fr Autre numéro
other phone addressbook fr Autre téléphone
-owerview addressbook fr Vue globale
pager common fr Pager
parcel addressbook fr Paquet
phone number common fr Numéro de téléphone
@@ -118,24 +113,21 @@ read a list of entries. addressbook fr Lire une liste d'entr
read a single entry by passing the id and fieldlist. addressbook fr Lire une seule entrée en passant l'ID et la liste des champs.
record access addressbook fr Enregistrer l'accès
record owner addressbook fr Enregistrer le propriétaire
-remote search addressbook fr Recherche à distance
retrieve contacts admin fr Récupérer les contacts
-select the type of conversion addressbook fr Choisissez le type de conversion
select where you want to store admin fr Choisissez où vous voulez stocker
show birthday reminders on main screen addressbook fr Montrer les rappels d'anniversaires sur la page principale
-show contact addressbook fr Montrer le contact
startrecord addressbook fr Enregistrement de départ
state common fr Région
street common fr Rue
suffix addressbook fr Suffixe
test import (show importable records only in browser) addressbook fr Tester l'import (montrer seulement les enregistrements importables dans le navigateur)
that field name has been used already ! addressbook fr Ce nom de champ a déjà été utilisé !
-the File menu and export your contacts into a comma separated text (CSV) file.
Or, in Palm Desktop 4.0 or greater, visit your addressbook and select Export from the File menu. The file exported will be in VCard format.
addressbook fr le menu Fichier et exportez vos contacts dans un fichier aux champs séparés par des virgules (CSV).
Ou, dans Palm Desktop 4.0 ou plus, allez dans votre carnet d'adresses et choisissez Exporter depuis le menu Fichier . Le fichier exporté sera dans le format VCard.
this person's first name was not in the address book. addressbook fr Le prénom de cette personne n'était pas dans le carnet d'adresses.
this person's last name was not in the address book. addressbook fr Le nom de cette personne n'était pas dans le carnet d'adresses.
today is %1's birthday! common fr Aujourd'hui c'est l'anniversaire de %1 !
tomorrow is %1's birthday. common fr Demain c'est l'anniversaire de %1.
update a single entry by passing the fields. addressbook fr Mettre à jour une seule entrée en passant les champs.
+use country list addressbook fr Utiliser la liste des pays
vcard common fr VCard
vcards require a first name entry. addressbook fr Les VCards nécessitent une entrée Prénom.
vcards require a last name entry. addressbook fr Les Vcards nécessitent une entrée nom de famille.
diff --git a/addressbook/setup/phpgw_ja.lang b/addressbook/setup/phpgw_ja.lang
index 95af2fa994..97c01dfffe 100644
--- a/addressbook/setup/phpgw_ja.lang
+++ b/addressbook/setup/phpgw_ja.lang
@@ -88,7 +88,7 @@ suffix addressbook ja
that field name has been used already ! addressbook ja ¹àÌÜ̾¤Ï´û¤Ë¸ºß¤·¤Æ¤¤¤Þ¤¹¡£
this person's first name was not in the address book. addressbook ja ¥¢¥É¥ì¥¹Ä¢¤Ë̾Á°¤¬¤¢¤ê¤Þ¤»¤ó¡£
today is %1's birthday! common ja º£Æü¤Ï %1 ¤µ¤ó¤ÎÃÂÀ¸Æü¤Ç¤¹¡£
-tomorrow is %1's birthday. common ja ÌÀÆü¤Ï %1 ¤µ¤ó¤ÎÃÂÀ¸Æü¤Ç¤¹¡£
+tommorow is %1's birthday. common ja ÌÀÆü¤Ï %1 ¤µ¤ó¤ÎÃÂÀ¸Æü¤Ç¤¹¡£
url addressbook ja URL
vcard common ja VCard
vcards require a first name entry. addressbook ja VCard ¤Ë¤Ï¡¢Ì¾Á°¤¬É¬ÍפǤ¹¡£
diff --git a/addressbook/setup/setup.inc.php b/addressbook/setup/setup.inc.php
index 9f9e15eb2f..77a3288772 100755
--- a/addressbook/setup/setup.inc.php
+++ b/addressbook/setup/setup.inc.php
@@ -13,23 +13,13 @@
/* Basic information about this app */
$setup_info['addressbook']['name'] = 'addressbook';
- $setup_info['addressbook']['version'] = '0.9.13.003';
+ $setup_info['addressbook']['title'] = 'Addressbook';
+ $setup_info['addressbook']['version'] = '0.9.13.002';
$setup_info['addressbook']['app_order'] = 4;
$setup_info['addressbook']['enable'] = 1;
- $setup_info['addressbook']['author'][] = array
- (
- 'name' => 'Joseph Engo',
- 'email' => 'jengo@phpgroupware.org'
- );
-
- $setup_info['addressbook']['author'][] = array
- (
- 'name' => 'Miles Lott',
- 'email' => 'milos@speakeasy.net'
- );
-
- $setup_info['addressbook']['note'] = 'The phpgwapi manages contact data. Addressbook manages servers for its remote capability';
+ $setup_info['addressbook']['author'] = 'Joseph Engo, Miles Lott';
+ $setup_info['addressbook']['note'] = 'The phpgwapi manages contact data. Addressbook manages servers for its remote capability.';
$setup_info['addressbook']['license'] = 'GPL';
$setup_info['addressbook']['description'] =
'Contact manager with Vcard support.
@@ -37,28 +27,24 @@
It makes use of the phpgroupware contacts class to store and retrieve
contact information via SQL or LDAP.';
- $setup_info['addressbook']['maintainer'] = '';
-
- /* Tables */
- $setup_info['addressbook']['tables'][] = 'phpgw_addressbook_servers';
+ $setup_info['addressbook']['maintainer'] = 'phpGroupWare coreteam';
+ $setup_info['addressbook']['maintainer_email'] = 'phpgroupware-developers@gnu.org';
/* The hooks this app includes, needed for hooks registration */
- $setup_info['addressbook']['hooks'] = array
- (
- 'admin',
- 'add_def_pref',
- 'config_validate',
- 'home',
- 'deleteaccount',
- 'notifywindow',
- 'preferences',
- 'help'
- );
+ $setup_info['addressbook']['hooks'][] = 'admin';
+ $setup_info['addressbook']['hooks'][] = 'add_def_pref';
+ $setup_info['addressbook']['hooks'][] = 'config_validate';
+ $setup_info['addressbook']['hooks'][] = 'home';
+ $setup_info['addressbook']['hooks'][] = 'manual';
+ $setup_info['addressbook']['hooks'][] = 'addaccount';
+ $setup_info['addressbook']['hooks'][] = 'editaccount';
+ $setup_info['addressbook']['hooks'][] = 'deleteaccount';
+ $setup_info['addressbook']['hooks'][] = 'notifywindow';
+ $setup_info['addressbook']['hooks'][] = 'preferences';
/* Dependencies for this app to work */
- $setup_info['addressbook']['depends'][] = array
- (
- 'appname' => 'phpgwapi',
- 'versions' => Array('0.9.15', '0.9.16')
+ $setup_info['addressbook']['depends'][] = array(
+ 'appname' => 'phpgwapi',
+ 'versions' => Array('0.9.13', '0.9.14')
);
?>
diff --git a/addressbook/setup/tables_baseline.inc.php b/addressbook/setup/tables_baseline.inc.php
deleted file mode 100644
index 51f6ebdce4..0000000000
--- a/addressbook/setup/tables_baseline.inc.php
+++ /dev/null
@@ -1,14 +0,0 @@
-
diff --git a/addressbook/setup/tables_update.inc.php b/addressbook/setup/tables_update.inc.php
deleted file mode 100644
index 392e965e26..0000000000
--- a/addressbook/setup/tables_update.inc.php
+++ /dev/null
@@ -1,36 +0,0 @@
-oProc->CreateTable(
- 'phpgw_addressbook_servers', array(
- 'fd' => array(
- 'name' => array('type' => 'varchar', 'precision' => 64, 'nullable' => False),
- 'basedn' => array('type' => 'varchar', 'precision' => 255, 'nullable' => True),
- 'search' => array('type' => 'varchar', 'precision' => 32, 'nullable' => True),
- 'attrs' => array('type' => 'varchar', 'precision' => 255, 'nullable' => True),
- 'enabled' => array('type' => 'int', 'precision' => 4)
- ),
- 'pk' => array('name'),
- 'fk' => array(),
- 'ix' => array(),
- 'uc' => array()
- )
- );
-
- $GLOBALS['setup_info']['addressbook']['currentver'] = '0.9.13.003';
- return $GLOBALS['setup_info']['addressbook']['currentver'];
- }
-?>
diff --git a/addressbook/templates/default/about.tpl b/addressbook/templates/default/about.tpl
new file mode 100644
index 0000000000..0b819b76e9
--- /dev/null
+++ b/addressbook/templates/default/about.tpl
@@ -0,0 +1,16 @@
+
+
+
+
+
+
+
+ {about_addressbook}
+
+
+ {appear} {agent} {version} {on} {platform}.
+
+
+
+
+
diff --git a/addressbook/templates/default/add.tpl b/addressbook/templates/default/add.tpl
index a2c7f29ab8..1389086489 100644
--- a/addressbook/templates/default/add.tpl
+++ b/addressbook/templates/default/add.tpl
@@ -1,17 +1,14 @@
-
diff --git a/addressbook/inc/hook_admin.inc.php b/addressbook/inc/hook_admin.inc.php
index d13b4665a9..290e519306 100644
--- a/addressbook/inc/hook_admin.inc.php
+++ b/addressbook/inc/hook_admin.inc.php
@@ -2,24 +2,24 @@
/**************************************************************************\
* phpGroupWare *
* http://www.phpgroupware.org *
- * Written by coreteam *
- * ----------------------------------------------------- *
+ * Written by Joseph Engo *
+ * -------------------------------------------- *
* This program is free software; you can redistribute it and/or modify it *
* under the terms of the GNU General Public License as published by the *
* Free Software Foundation; either version 2 of the License, or (at your *
* option) any later version. *
\**************************************************************************/
- /* $Id$ */
- {
-// Only Modify the $file variable.....
- $file = Array
- (
- 'Site Configuration' => $GLOBALS['phpgw']->link('/index.php','menuaction=admin.uiconfig.index&appname=' . $appname),
- 'Edit custom fields' => $GLOBALS['phpgw']->link('/index.php','menuaction=addressbook.uifields.index'),
- 'Global Categories' => $GLOBALS['phpgw']->link('/index.php','menuaction=admin.uicategories.index&appname=' . $appname . '&global_cats=True')
- );
-//Do not modify below this line
- $GLOBALS['phpgw']->common->display_mainscreen($appname,$file);
- }
-?>
+ // $Id$
+ // $Source$
+
+ // Only Modify the $file and $title variables.....
+ $title = $appname;
+ $file = Array(
+ 'Site Configuration' => $GLOBALS['phpgw']->link('/index.php','menuaction=admin.uiconfig.index&appname=' . $appname),
+ 'Edit custom fields' => $GLOBALS['phpgw']->link('/index.php','menuaction=addressbook.uifields.index'),
+ 'Global Categories' => $GLOBALS['phpgw']->link('/index.php','menuaction=admin.uicategories.index&appname=addressbook')
+ );
+ //Do not modify below this line
+ display_section($appname,$title,$file);
+?>
\ No newline at end of file